#
# EDOS testing framework
# Copyright (C) 2006 EDGE-IT
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 2 as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
# 02111-1307, USA.
#

#
# Author: Francois Dechelle <fdechelle@mandriva.com>
#
    
import md5
import subprocess
import datetime

def makeTestReportId(*args):
    m = md5.new()
    command = "/bin/uname -a"
    p = subprocess.Popen( command, shell=True, stdin=None, stdout=subprocess.PIPE, stderr=None, close_fds=True)
    p.wait()
    m.update( p.stdout.read())
    m.update( str(datetime.datetime.utcnow()))
    for a in args:
        m.update( a)
    return m.hexdigest()

class TestReporter:
    """ Abstract base class of test reporters"""

    def reportPlatform(self, **args):
        raise NotImplementedError

    def reportRunning(self, **args):
        raise NotImplementedError

    def reportCompleted(self, **args):
        raise NotImplementedError

class MultiReporter(TestReporter):
    def __init__(self,reporters):
        self.__reporters__ = reporters

    def __str__(self):
        s = ''
        count = 0
        for r in self.__reporters__:
            s += "[%d] %s\n" % (count,str(r))
            count = count + 1
        return s

    def reportPlatform(self, **args):
        for r in self.__reporters__:
            r.reportPlatform(**args)

    def reportRunning(self, **args):
        for r in self.__reporters__:
            r.reportRunning(**args)

    def reportCompleted(self, **args):
        for r in self.__reporters__:
            r.reportCompleted(**args)

class NullReporter(TestReporter):
    def reportPlatform(self, **args):
        pass

    def reportRunning(self, **args):
        pass

    def reportCompleted(self, **args):
        pass

